@@ -34,6 +34,7 @@
                      [plugin      :refer [load-plugin load-plugins]]
                      [pubsub      :as pubsub]
                      [pushover    :refer [pushover]]
+                     [rabbitmq    :refer [rabbitmq]]
                      [repl]
                      [service     :as service]
                      [shinken     :refer [shinken]]
@@ -50,13 +51,15 @@
                      [time        :refer [unix-time linear-time once! every!]]
                      [twilio      :refer [twilio]]
                      [victorops   :refer [victorops]]
-                     [xymon       :refer [xymon]]]
+                     [xymon       :refer [xymon]]
+                     [zabbix      :refer [zabbix]]]
             [riemann.transport [tcp        :as tcp]
                                [udp        :as udp]
                                [websockets :as websockets]
                                [sse        :as sse]
                                [graphite   :as graphite]
-                               [opentsdb   :as opentsdb]]
+                               [opentsdb   :as opentsdb]
+                               [rabbitmq   :as rabbitmq]]
             [cemerick.pomegranate :refer [add-dependencies]]
             [clojure.java.io :refer [file]]
             [clojure.tools.nrepl.server :as repl]
@@ -178,6 +181,20 @@
   [& opts]
   (service! (sse/sse-server (kwargs-or-map opts))))
 
+(defn rabbitmq-transport
+  "Add a new RabbitMQ transport to the default core.
+
+  ```
+  (rabbitmq-transport {:host \"localhost\"
+                       :port 5672
+                       :riemann.exchange-settings {:name \"riemann\"
+                                                   :auto-delete true}
+                       :riemann.routing-key \"riemann.events\"})
+  ```
+  "
+  [& opts]
+  (service! (rabbitmq/rabbitmq-transport (kwargs-or-map opts))))
+
 (defn kafka-consumer
   "Add a new kafka consumer with opts to the default core.
 
