@@ -1,5 +1,5 @@
 (ns riemann.influxdb
-  "Forwards events to InfluxDB. Supports InfluxDB 0.9 or Higher"
+  "Forwards events to InfluxDB. Supports InfluxDB 0.9 or higher."
   (:require
     [clojure.set :as set])
   (:import
@@ -21,9 +21,10 @@
 
 ;; specific influxdb-deprecated code
 (defn event-tags
-  "Generates a map of InfluxDB tags from a Riemann event. Any fields in the
-  event which are named in `tag-fields` will be converted to a string key/value
-  entry in the tag map."
+  "Generates a map of InfluxDB tags from a Riemann event.
+
+  Any fields in the event which are named in `tag-fields` will be converted to
+  a string key/value entry in the tag map."
   [tag-fields event]
   (->> (select-keys event tag-fields)
        (remove (fn [[k v]] (nil-or-empty-str v)))
@@ -32,10 +33,10 @@
 
 ;; specific influxdb-deprecated code
 (defn event-fields
-  "Generates a map of InfluxDB fields from a Riemann event. The event's
-  `metric` is converted to the `value` field, and any additional event fields
-  which are not standard Riemann properties or in `tag-fields` will also be
-  present."
+  "Generates a map of InfluxDB fields from a Riemann event.
+
+  The event's `metric` is converted to the `value` field, and any additional
+  event fields which are not standard Riemann properties or in `tag-fields` will also  be present."
   [tag-fields event]
   (let [ignored-fields (set/union special-fields tag-fields)]
     (-> event
@@ -47,7 +48,7 @@
 
 (defn get-trust-manager
   "Returns an array with an instance of `X509TrustManager`
-  Used for trust all certs in the influxdb `insecure` mode."
+  Used for trust all certs in the InfluxDB `insecure` mode."
   []
   (let [trust-manager (proxy [X509TrustManager] []
                         (checkServerTrusted [_ _])
@@ -56,21 +57,21 @@
     (into-array (list trust-manager))))
 
 (defn get-ssl-factory
-  "Get an instance of `javax.net.ssl.SSLSocketFactory`"
+  "Get an instance of `javax.net.ssl.SSLSocketFactory`."
   []
   (let [ssl-context (SSLContext/getInstance "TLS")]
     (.init ssl-context nil (get-trust-manager) (new SecureRandom))
     (.getSocketFactory ssl-context)))
 
 (defn get-hostname-verifier
-  "Get an instance of `javax.net.ssl.HostnameVerifier`"
+  "Get an instance of `javax.net.ssl.HostnameVerifier`."
   []
   (let [verifier (proxy [HostnameVerifier] []
                    (verify [_ _] true))]
     verifier))
 
 (defn get-builder
-  "Returns a new okhttp3.OkHttpClient$Builder"
+  "Returns a new okhttp3.OkHttpClient$Builder."
   [{:keys [timeout insecure]}]
   (let [builder (new okhttp3.OkHttpClient$Builder)]
     (when insecure
@@ -82,13 +83,13 @@
       (.connectTimeout timeout TimeUnit/MILLISECONDS))))
 
 (defn get-client
-  "Returns an `org.influxdb.InfluxDB` instance"
+  "Returns an `org.influxdb.InfluxDB` instance."
   [{:keys [scheme host port username password] :as opts}]
   (let [url (str scheme "://" host ":" port)]
     (InfluxDBFactory/connect url username password (get-builder opts))))
 
 (defn get-batchpoint
-  "Returns a `org.influxdb.dto.BatchPoints` instance"
+  "Returns a `org.influxdb.dto.BatchPoints` instance."
   [{:keys [tags db retention consistency]}]
   (let [builder (doto (BatchPoints/database db)
                       (.consistency (InfluxDB$ConsistencyLevel/valueOf consistency)))]
@@ -97,9 +98,11 @@
     (.build builder)))
 
 (defn get-time-unit
-  "returns a value from the TimeUnit enum depending of the `precision` parameters.
-  The `precision` parameter is a keyword whose possibles values are `:seconds`, `:milliseconds` and `:microseconds`.
-  Returns `TimeUnit/SECONDS` by default"
+  "Returns a value from the TimeUnit enum depending of the `precision` parameters.
+
+  The `precision` parameter is a keyword whose possible values are `:seconds`, `:milliseconds` and `:microseconds`.
+
+  Returns `TimeUnit/SECONDS` by default."
   [precision]
   (cond
     (= precision :milliseconds) TimeUnit/MILLISECONDS
@@ -109,8 +112,10 @@
 
 (defn convert-time
   "Converts the `time-event` parameter (which is time second) in a new time unit specified by the `precision` parameter. It also converts the time to long.
-  The `precision` parameter is a keyword whose possibles values are `:seconds`, `:milliseconds` and `:microseconds`.
-  Returns time in seconds by default"
+
+  The `precision` parameter is a keyword whose possible values are `:seconds`, `:milliseconds` and `:microseconds`.
+
+  Returns time in seconds by default."
   [time-event precision]
   (cond
     (= precision :milliseconds) (long (* 1000 time-event))
@@ -119,7 +124,7 @@
     true (long time-event)))
 
 (defn converts-double
-  "if n if a ratio or a BigInt, converts it to double. Returns n otherwise"
+  "if n if a ratio or a BigInt, converts it to double. Returns n otherwise."
   [n]
   (if (or (ratio? n) (instance? clojure.lang.BigInt n))
     (double n)
@@ -128,8 +133,9 @@
 ;; specific influxdb-deprecated code
 (defn event->point-9
   "Converts a Riemann event into an InfluxDB Point (an instance of `org.influxdb.dto.Point`.
-  The first parameter is the event. The `:precision` key of the event is used to converts the event `time` into the correct time unit (default seconds).
-  The second parameter is the option map passed to the influxdb stream."
+
+  - The first parameter is the event. The `:precision` key of the event is used to converts the event `time` into the correct time unit (default seconds).
+  - The second parameter is the option map passed to the InfluxDB stream."
   [event opts]
   (when (and (:time event) (:service event) (:metric event))
     (let [precision (:precision event (:precision opts))
@@ -144,11 +150,14 @@
 
 (defn event->point
   "Converts a Riemann event into an InfluxDB Point (an instance of `org.influxdb.dto.Point`.
-  The first parameter is the event.
-  The `:precision` event key is used to converts the event `time` into the correct time unit (default seconds).
-  The `:measurement` event key is the influxdb measurement.
-  The `:influxdb-tags` event key contains all the Influxdb tags.
-  The `:influxdb-fields` event key contains all the Influxdb fields.
+
+  The first parameter is the event:
+
+    - The `:precision` event key is used to converts the event `time` into the correct time unit (default seconds).
+    - The `:measurement` event key is the influxdb measurement.
+    - The `:influxdb-tags` event key contains all the Influxdb tags.
+    - The `:influxdb-fields` event key contains all the Influxdb fields.
+
   The second parameter is the option map passed to the influxdb stream."
   [event opts]
   (when (and (:time event) (:measurement event))
@@ -177,14 +186,16 @@
    :insecure false})
 
 (defn write-batch-point
-  "Write to influxdb the `batch-point` using the `connection`"
+  "Write to InfluxDB the `batch-point` using the `connection`."
   [^InfluxDB connection batch-point]
   (.write connection batch-point))
 
 (defn get-batchpoints
   "Create a `org.influxdb.dto.BatchPoints` for each element in the `events` list.
   `events` is a list where each element is a list of events.
+
   Each element contains events with the same `:db`, `:retention` and `:consistency` keys.
+
   These options are used to create the BatchPoints.
   `opts` are the global influxdb stream options."
   [opts events]
@@ -201,7 +212,8 @@
 
 (defn partition-events
   "`events` is a list of events.
-  partition `events` depending of the `db`, `retention` and `consistency` keys
+
+  Partition `events` depending of the `db`, `retention` and `consistency` keys
   returns a list, each element being a list of events (the result of the partitioning)."
   [events]
   (->> (if (sequential? events) events (list events))
@@ -212,14 +224,15 @@
   "Returns a function which accepts an event, or sequence of events, and writes
   them to InfluxDB.
 
-  streams receive an event or a list of events. Each event can have these keys :
-  `:measurement`     The influxdb measurement.
-  `:influxdb-tags`   A map of influxdb tags. Exemple : `{:foo \"bar\"}`
-  `:influxdb-fields` A map of influxdb fields. Exemple : `{:bar \"baz\"}`
-  `:precision`       The time precision. Possibles values are `:seconds`, `:milliseconds` and `:microseconds` (default `:seconds`). The event `time` will be converted.
-  `:db`              Name of the database to write to. (optional)
-  `:retention`       Name of retention policy to use. (optional)
-  `:consistency`     The InfluxDB consistency level (default: `\"ONE\"`). Possibles values are ALL, ANY, ONE, QUORUM."
+  Streams receive an event or a list of events. Each event can have these keys:
+
+  - `:measurement`     The InfluxDB measurement.
+  - `:influxdb-tags`   A map of InfluxDB tags. Example: `{:foo \"bar\"}`
+  - `:influxdb-fields` A map of InfluxDB fields. Example: `{:bar \"baz\"}`
+  - `:precision`       The time precision. Possibles values are `:seconds`, `:milliseconds` and `:microseconds` (default `:seconds`). The event `time` will be converted.
+  - `:db`              Name of the database to write to (optional).
+  - `:retention`       Name of retention policy to use (optional).
+  - `:consistency`     The InfluxDB consistency level (default: `\"ONE\"`). Possibles values are ALL, ANY, ONE, QUORUM."
   [opts]
   (let [opts (merge default-opts opts)
         connection (get-client opts)]
@@ -234,13 +247,15 @@
   "Returns a function which accepts an event, or sequence of events, and writes
   them to InfluxDB.
 
-  influxdb-deprecated specifics options :
-  `:tag-fields`     A set of event fields to map into InfluxDB series tags.
+  InfluxDB-deprecated specifics options:
+
+  - `:tag-fields`     A set of event fields to map into InfluxDB series tags.
                     (default: `#{:host}`).
 
-  Each event can have these keys :
-  `:tag-fields`     A set of event fields to map into InfluxDB series tags..
-  `:precision`       The time precision. Possibles values are `:seconds`, `:milliseconds` and `:microseconds` (default `:seconds`). The event `time` will be converted."
+  Each event can have these keys:
+
+  - `:tag-fields`     A set of event fields to map into InfluxDB series tags.
+  - `:precision`       The time precision. Possibles values are `:seconds`, `:milliseconds` and `:microseconds` (default `:seconds`). The event `time` will be converted."
   [opts]
   (let [opts (merge default-opts opts)
         connection (get-client opts)]
@@ -257,25 +272,31 @@
   "Returns a function which accepts an event, or sequence of events, and writes
   them to InfluxDB as a batch of measurement points. For performance, you should
   wrap this stream with `batch` or an asynchronous queue.
-  Support InfluxdbDB 0.9 and higher.
+
+  Support InfluxDB 0.9 and higher.
+
+  ```clojure
   (influxdb {:host \"influxdb.example.com\"
              :db \"my_db\"
-             :user \"riemann\"
+             :username \"riemann\"
              :password \"secret\"})
+  ```
+
   General Options:
-  `:db`             Name of the database to write to. (default: `\"riemann\"`)
-  `:version`        Version of InfluxDB client to use. (default: `\":deprecated\"`)
-  `:scheme`         URL scheme for endpoint. (default: `\"http\"`)
-  `:host`           Hostname to write points to. (default: `\"localhost\"`)
-  `:port`           API port number. (default: `8086`)
-  `:username`       Database user to authenticate as. (default: `\"root\"`)
-  `:password`       Password to authenticate with. (optional)
-  `:tags`           A common map of tags to apply to all points. (optional)
-  `:retention`      Name of retention policy to use. (optional)
-  `:timeout`        HTTP timeout in milliseconds. (default: `5000`)
-  `:consistency`    The InfluxDB consistency level (default: `\"ONE\"`). Possibles values are ALL, ANY, ONE, QUORUM.
-  `:insecure`       If scheme is https and certficate is self-signed. (optional)
-  `:precision`      The time precision. Possibles values are `:seconds`, `:milliseconds` and `:microseconds` (default `:seconds`). The event `time` will be converted.
+
+  - `:db`             Name of the database to write to. (default: `\"riemann\"`)
+  - `:version`        Version of InfluxDB client to use. (default: `\":deprecated\"`)
+  - `:scheme`         URL scheme for endpoint. (default: `\"http\"`)
+  - `:host`           Hostname to write points to. (default: `\"localhost\"`)
+  - `:port`           API port number. (default: `8086`)
+  - `:username`       Database user to authenticate as. (default: `\"root\"`)
+  - `:password`       Password to authenticate with. (optional)
+  - `:tags`           A common map of tags to apply to all points. (optional)
+  - `:retention`      Name of retention policy to use. (optional)
+  - `:timeout`        HTTP timeout in milliseconds. (default: `5000`)
+  - `:consistency`    The InfluxDB consistency level (default: `\"ONE\"`). Possibles values are ALL, ANY, ONE, QUORUM.
+  - `:insecure`       If scheme is https and certficate is self-signed. (optional)
+  - `:precision`      The time precision. Possibles values are `:seconds`, `:milliseconds` and `:microseconds` (default `:seconds`). The event `time` will be converted.
 
   See `influxdb-deprecated` and `influxdb-new-stream` for version-specific options."
   [opts]
